PluginWorld

Struct PluginWorld 

pub struct PluginWorld { /* private fields */ }
Auto-generated bindings for an instance a component which implements the world plugin-world.

This structure can be created through a number of means depending on your requirements and what you have on hand:

These methods are all equivalent to one another and move around the tradeoff of what work is performed when.

Implementations

Source

impl PluginWorld

pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<PluginWorld>

Convenience wrapper around PluginWorldPre::new and PluginWorldPre::instantiate.

pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<PluginWorld>

pub fn add_to_linker<T, U>( linker: &mut Linker<T>, get: impl Fn(&mut T) -> &mut U + Send + Sync + Copy + 'static, ) -> Result<()>
where U: Host + Host + Host + Host + Host + Host,

pub fn yosh_plugin_plugin(&self) -> &Guest

pub fn yosh_plugin_hooks(&self) -> &Guest