pub struct PluginWorldIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
plugin-world.
This is an implementation detail of PluginWorldPre and can
be constructed if needed as well.
For more information see PluginWorld as well.
Implementations
Sourceimpl PluginWorldIndices
impl PluginWorldIndices
Sourcepub fn new(component: &Component) -> Result<Self>
pub fn new(component: &Component) -> Result<Self>
Creates a new copy of PluginWorldIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn new_instance(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Self>
pub fn new_instance( store: impl AsContextMut, instance: &Instance, ) -> Result<Self>
Creates a new instance of PluginWorldIndices from an
instantiated component.
This method of creating a PluginWorld will perform string
lookups for all exports when this method is called. This
will only succeed if the provided instance matches the
requirements of PluginWorld.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<PluginWorld>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<PluginWorld>
Uses the indices stored in self to load an instance
of PluginWorld from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.