pub struct PluginWorld { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world plugin-world.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
PluginWorld::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
PluginWorldPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesPluginWorldPre::instantiateto create aPluginWorld. -
If you’ve instantiated the instance yourself already then you can use
PluginWorld::new. -
You can also access the guts of instantiation through
PluginWorldIndices::new_instancefollowed byPluginWorldIndices::loadto crate an instance of this type.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl PluginWorld
impl PluginWorld
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<PluginWorld>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<PluginWorld>
Convenience wrapper around PluginWorldPre::new and
PluginWorldPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<PluginWorld>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<PluginWorld>
Convenience wrapper around PluginWorldIndices::new_instance and
PluginWorldIndices::load.
pub fn add_to_linker<T, U>( linker: &mut Linker<T>, get: impl Fn(&mut T) -> &mut U + Send + Sync + Copy + 'static, ) -> Result<()>
pub fn yosh_plugin_plugin(&self) -> &Guest
pub fn yosh_plugin_hooks(&self) -> &Guest